@@ -88,4 +88,4 @@ simulate(
          seed=1165270654L
          ) -> gillespie.sir
 
-save(gillespie.sir,file="gillespie.sir.rda")
+save(gillespie.sir,file="gillespie.sir.rda",compress="xz")
